Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(22)

Unified Diff: src/IceTargetLowering.h

Issue 870653002: Subzero: Initial implementation of multithreaded translation. (Closed) Base URL: https://chromium.googlesource.com/native_client/pnacl-subzero.git@master
Patch Set: Fix getErrorStatus() usage in BitcodeMunger Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/IceTargetLowering.h
diff --git a/src/IceTargetLowering.h b/src/IceTargetLowering.h
index f2e5863b255990720168040bb6940534692751fa..f60812abb75b7116c9b82d8f1d004d9813de6748 100644
--- a/src/IceTargetLowering.h
+++ b/src/IceTargetLowering.h
@@ -202,8 +202,6 @@ public:
virtual void addProlog(CfgNode *Node) = 0;
virtual void addEpilog(CfgNode *Node) = 0;
- virtual void emitConstants() const = 0;
-
virtual ~TargetLowering() {}
protected:
@@ -245,23 +243,22 @@ protected:
LoweringContext Context;
};
-// TargetGlobalInitLowering is used for "lowering" global
-// initializers. It is separated out from TargetLowering because it
-// does not require a Cfg.
-class TargetGlobalInitLowering {
- TargetGlobalInitLowering(const TargetGlobalInitLowering &) = delete;
- TargetGlobalInitLowering &operator=(const TargetGlobalInitLowering &) =
- delete;
+// TargetGlobalLowering is used for "lowering" global initializers,
+// including the internal constant pool. It is separated out from
+// TargetLowering because it does not require a Cfg.
+class TargetGlobalLowering {
+ TargetGlobalLowering(const TargetGlobalLowering &) = delete;
+ TargetGlobalLowering &operator=(const TargetGlobalLowering &) = delete;
JF 2015/01/23 17:22:43 TargetGlobalLowering() = delete;
Jim Stichnoth 2015/01/23 21:54:02 Done. (also for TargetGlobalX8632)
public:
- static TargetGlobalInitLowering *createLowering(TargetArch Target,
- GlobalContext *Ctx);
- virtual ~TargetGlobalInitLowering();
+ static TargetGlobalLowering *createLowering(GlobalContext *Ctx);
+ virtual ~TargetGlobalLowering();
- virtual void lower(const VariableDeclaration &Var) = 0;
+ virtual void lowerInit(const VariableDeclaration &Var) const = 0;
+ virtual void lowerConstants(GlobalContext *Ctx) const = 0;
protected:
- TargetGlobalInitLowering(GlobalContext *Ctx) : Ctx(Ctx) {}
+ TargetGlobalLowering(GlobalContext *Ctx) : Ctx(Ctx) {}
GlobalContext *Ctx;
};
« src/IceGlobalContext.cpp ('K') | « src/IceRegAlloc.cpp ('k') | src/IceTargetLowering.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698